@@ -16,11 +16,11 @@
  *    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
  */
  /**
-  * @file engine.c
+  * @file estardict-engine.c
   * @author Luca Vaudano
   */
 #include "estardict-engine.h"
-
+#include "estardict-engine-strip.h"
 
 // IFO
 const guint IFO_FILE_MAX_LENGHT_LINE = 100;
@@ -599,11 +599,12 @@ gchar* parseDefinition(StarDictInfo* starDictInfo, gchar* dictText) {
  *
  * @param starDictInfo Dictionary
  * @param word Word to search
+ * @param diatrics Consider diatrics when search
  * @return Coordinates for the given word and dictionary, NULL if not
  * found or in case of error (in this case the estardictEngineError
  * is valued)
  */
-WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word) {
+WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gboolean diacritics) {
     g_debug("-> %s %s()", __FILE__, __FUNCTION__);
 
     WordCoordinates* coordinates = NULL;
@@ -619,6 +620,7 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word) {
             gchar buffer[COORDINATES_BUFFER_LENGTH + 1];
 
             gchar* tmp = NULL;
+            gchar* tmp1 = NULL;
             guint len = 0;
             guint wordLenght = strlen(word);
             gboolean continueRead = FALSE;
@@ -648,10 +650,22 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word) {
                 // Loop over buffer size
                 while (pos < min) {
 
+                    // Normalize the word without diatrics
+                    // e.g. espátula
+                    if (diacritics) {
+                        tmp1 = strip(tmp);
+                        //g_debug("Search stripped word %s", tmp1);
+                    }
+
                     // we have found word in dictionary
-                    if ( g_ascii_strncasecmp(tmp, word, wordLenght) == 0 &&
-                        strlen(tmp) == wordLenght
+                    if ( 
+                     ( strlen(tmp) == wordLenght && g_ascii_strncasecmp(tmp, word, wordLenght) == 0 )
+                     || ( diacritics && tmp1 != NULL && strlen(tmp1) == wordLenght && g_ascii_strncasecmp(tmp1, word, wordLenght) == 0 )
                     ) {
+                        
+                        if ( diacritics ) {
+                            word = g_strdup(tmp);
+                        }
 
                         // Ignore the first word inside the loop cycle
                         // it could be partial
@@ -887,8 +901,16 @@ char* getDefinition(StarDictInfo* starDictInfo, gchar* word) {
     g_debug("%s %s", starDictInfo->bookname, word);
 
     char* definition = NULL;
+    WordCoordinates* coordinates = NULL;
 
-    WordCoordinates* coordinates = getWordCoordinates(starDictInfo, word);
+    coordinates = getWordCoordinates(starDictInfo, word, FALSE);
+
+    if ( coordinates == NULL
+        && estardictEngineError != ESTARDICT_ENGINE_ERROR_READING_IDX 
+        && estardictEngineError != ESTARDICT_ENGINE_ERROR_OPEN_IDX
+        && isPlainLetters(word) ) {
+            coordinates = getWordCoordinates(starDictInfo, word, TRUE);
+    }
 
     // Word found
     if ( coordinates != NULL ) {
