@@ -236,17 +236,13 @@ static void newDictionarySelect(void *data, Evas_Object *obj, void *event_info)
 
     if (selected) {
 
-        // If it is a directory
-        if ( selected[strlen(selected)-1] == '/' ) {
-            dictionaryPath = g_strndup(selected, strlen(selected)-1) ;
-            addDictionaryToGenlist(dictionaryPath);
+        // It is a directory, check made by the UI
+        g_debug("directory selected %s", selected);
+        dictionaryPath = g_strdup(selected) ;
+        addDictionaryToGenlist(dictionaryPath);
 
-             // Delete the parent window
-            evas_object_del(data);
-        } else {
-            g_message("You have to select the dictionary directory.");
-            createDialog( (Evas_Object *)data, addSpaces(DIALOG_SELECT_DICTIONARY) );
-        }
+         // Delete the parent window
+        evas_object_del(data);
 
     // Cancel from file selector
     } else {
